All of lore.kernel.org
 help / color / mirror / Atom feed
From: alexs@kernel.org
To: Matthew Wilcox <willy@infradead.org>,
	Andrea Arcangeli <aarcange@redhat.com>,
	Izik Eidus <izik.eidus@ravellosystems.com>,
	david@redhat.com, Andrew Morton <akpm@linux-foundation.org>,
	linux-mm@kvack.org, linux-kernel@vger.kernel.org,
	ryncsn@gmail.com
Cc: "Alex Shi (tencent)" <alexs@kernel.org>,
	Hugh Dickins <hughd@google.com>,
	Chris Wright <chrisw@sous-sol.org>
Subject: [PATCH v3 04/14] mm/ksm: use folio in remove_stable_node
Date: Mon, 25 Mar 2024 20:48:51 +0800	[thread overview]
Message-ID: <20240325124904.398913-5-alexs@kernel.org> (raw)
In-Reply-To: <20240325124904.398913-1-alexs@kernel.org>

From: "Alex Shi (tencent)" <alexs@kernel.org>

pages in stable tree are all single normal page, so uses ksm_get_folio()
and folio_set_stable_node(), also saves 3 calls to compound_head().

Signed-off-by: Alex Shi (tencent) <alexs@kernel.org>
Cc: Izik Eidus <izik.eidus@ravellosystems.com>
Cc: Matthew Wilcox <willy@infradead.org>
Cc: Andrea Arcangeli <aarcange@redhat.com>
Cc: Hugh Dickins <hughd@google.com>
Cc: Chris Wright <chrisw@sous-sol.org>
---
 mm/ksm.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/mm/ksm.c b/mm/ksm.c
index c9b7c5701f22..b6ee2bc7646f 100644
--- a/mm/ksm.c
+++ b/mm/ksm.c
@@ -1121,11 +1121,11 @@ static inline void folio_set_stable_node(struct folio *folio,
  */
 static int remove_stable_node(struct ksm_stable_node *stable_node)
 {
-	struct page *page;
+	struct folio *folio;
 	int err;
 
-	page = get_ksm_page(stable_node, GET_KSM_PAGE_LOCK);
-	if (!page) {
+	folio = ksm_get_folio(stable_node, GET_KSM_PAGE_LOCK);
+	if (!folio) {
 		/*
 		 * get_ksm_page did remove_node_from_stable_tree itself.
 		 */
@@ -1138,22 +1138,22 @@ static int remove_stable_node(struct ksm_stable_node *stable_node)
 	 * merge_across_nodes/max_page_sharing be switched.
 	 */
 	err = -EBUSY;
-	if (!page_mapped(page)) {
+	if (!folio_mapped(folio)) {
 		/*
 		 * The stable node did not yet appear stale to get_ksm_page(),
 		 * since that allows for an unmapped ksm page to be recognized
 		 * right up until it is freed; but the node is safe to remove.
 		 * This page might be in an LRU cache waiting to be freed,
 		 * or it might be PageSwapCache (perhaps under writeback),
 		 * or it might have been removed from swapcache a moment ago.
 		 */
-		set_page_stable_node(page, NULL);
+		folio_set_stable_node(folio, NULL);
 		remove_node_from_stable_tree(stable_node);
 		err = 0;
 	}
 
-	unlock_page(page);
-	put_page(page);
+	folio_unlock(folio);
+	folio_put(folio);
 	return err;
 }
 
@@ -1138,22 +1138,22 @@ static int remove_stable_node(struct ksm_stable_node *stable_node)
 		/*
 		 * The stable node did not yet appear stale to get_ksm_page(),
-		 * since that allows for an unmapped ksm page to be recognized
+		 * since that allows for an unmapped ksm folio to be recognized
 		 * right up until it is freed; but the node is safe to remove.
@@ -1138,22 +1138,22 @@ static int remove_stable_node(struct ksm_stable_node *stable_node)
 		 * right up until it is freed; but the node is safe to remove.
-		 * This page might be in an LRU cache waiting to be freed,
-		 * or it might be PageSwapCache (perhaps under writeback),
+		 * This folio might be in an LRU cache waiting to be freed,
+		 * or it might be in the swapcache (perhaps under writeback),
 		 * or it might have been removed from swapcache a moment ago.
 		 */
-- 
2.43.0


  parent reply	other threads:[~2024-03-25 12:45 UTC|newest]

Thread overview: 32+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-03-25 12:48 [PATCH v2 00/14] transfer page to folio in KSM alexs
2024-03-25 12:47 ` David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 01/14] mm/ksm: add ksm_get_folio alexs
2024-04-05  7:23   ` David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 02/14] mm/ksm: use folio in remove_rmap_item_from_tree alexs
2024-04-05  7:24   ` David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 03/14] mm/ksm: add folio_set_stable_node alexs
2024-04-05  7:25   ` David Hildenbrand
2024-03-25 12:48 ` alexs [this message]
2024-04-05  7:26   ` [PATCH v3 04/14] mm/ksm: use folio in remove_stable_node David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 05/14] mm/ksm: use folio in stable_node_dup alexs
2024-04-05  7:27   ` David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 06/14] mm/ksm: use ksm_get_folio in scan_get_next_rmap_item alexs
2024-04-05  7:28   ` David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 07/14] mm/ksm: use folio in write_protect_page alexs
2024-04-05  7:23   ` David Hildenbrand
2024-04-08  6:58     ` Alex Shi
2024-03-25 12:48 ` [PATCH v3 08/14] mm/ksm: Convert chain series funcs to use folio alexs
2024-04-05  7:36   ` David Hildenbrand
2024-03-25 12:48 ` [PATCH v3 09/14] mm/ksm: Convert stable_tree_insert " alexs
2024-03-25 12:48 ` [PATCH v3 10/14] mm/ksm: Convert stable_tree_search " alexs
2024-03-25 12:48 ` [PATCH v3 11/14] mm/ksm: remove get_ksm_page and related info alexs
2024-04-05  9:06   ` David Hildenbrand
2024-04-08  6:59     ` Alex Shi
2024-03-25 12:48 ` [PATCH v3 12/14] mm/ksm: return folio for chain series funcs alexs
2024-03-25 12:49 ` [PATCH v3 13/14] mm/ksm: use folio_set_stable_node in try_to_merge_one_page alexs
2024-04-05  9:06   ` David Hildenbrand
2024-03-25 12:49 ` [PATCH v3 14/14] mm/ksm: remove set_page_stable_node alexs
2024-04-05  7:32   ` David Hildenbrand
2024-04-08  7:00     ` Alex Shi
2024-04-05  9:07   ` David Hildenbrand
2024-04-08  7:01     ` Alex Shi

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240325124904.398913-5-alexs@kernel.org \
    --to=alexs@kernel.org \
    --cc=aarcange@redhat.com \
    --cc=akpm@linux-foundation.org \
    --cc=chrisw@sous-sol.org \
    --cc=david@redhat.com \
    --cc=hughd@google.com \
    --cc=izik.eidus@ravellosystems.com \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-mm@kvack.org \
    --cc=ryncsn@gmail.com \
    --cc=willy@infradead.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.